@@ -16,7 +16,7 @@ our @ISA = qw(Script::Toolbox::Util Script::Toolbox::Util::Opt Exporter);
 # This allows declaration	use Script::Toolbox ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(Open Log Exit Table Usage Dir File
+our %EXPORT_TAGS = ( 'all' => [ qw(Open Log Exit Table Usage Dir File FileC
 						           System Now Menue KeyMap Stat TmpFile
                                    DataMenue
                                   ) ] );
@@ -27,7 +27,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.47';
+our $VERSION = '0.49';
 
 
 # Preloaded methods go here.
@@ -318,7 +318,13 @@ Append records like  KEY$fieldSepVALUE$recSep to the file. Default record separa
 the empty string. Default field separator is ":";
 
 
+=item $arrRef = FileC("/path/to/file")
 
+Same as File("/path/to/file") but with chomped the results.
+
+=item $arrRef = FileC("/path/to/file", \&callback)
+
+Same as File("/path/to/file",  \&callback) but with chomped the results.
 
 
 
