@@ -22,7 +22,7 @@ our @ISA = qw(Exporter);
 # This allows declaration	use Script::Toolbox::Util ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(Open Log Exit Table Usage Dir File System Now Menue KeyMap Stat TmpFile DataMenue) ] );
+our %EXPORT_TAGS = ( 'all' => [ qw(Open Log Exit Table Usage Dir File FileC System Now Menue KeyMap Stat TmpFile DataMenue) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
@@ -30,7 +30,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.47';
+our $VERSION = '0.49';
 
 # Preloaded methods go here.
 sub _getKV(@);
@@ -375,6 +375,24 @@ sub GetOpt($)
 	return	$self->{'ops'}->get($opt);
 }
 
+#------------------------------------------------------------------------------
+# Read the entire file into  an array.
+# File can be a file name or an IO::File handle.
+# Chomp all array elements.
+#------------------------------------------------------------------------------
+sub FileC(@)
+{
+	my ($filename,$newContent) = _getParam(@_);
+
+    my $f = undef;
+	   if( !defined  $newContent) 	 { $f = _ReadFile($filename); }
+	elsif( ref $newContent eq 'CODE'){ $f = _ReadFile($filename,$newContent);}
+    else                             { return undef; }
+
+    chomp @{$f} if( defined $f );
+    return $f;
+}
+
 #------------------------------------------------------------------------------
 # Read the entire file into  an array or write the new content to the file.
 # File can be a file name or an IO::File handle.
@@ -874,7 +892,11 @@ sub Menue($)
     {
         next if( ! $op->{'label'} );
         my ($def,$form)=_getDefForm($form1,$op);
-        printf $form, $i++,$op->{'label'},$def;
+        if( defined $def ) {
+            printf $form, $i++,$op->{'label'},$def;
+        }else{
+            printf $form, $i++,$op->{'label'};
+        }
     }
     _printMenueFooter($opts);
     printf "\nSelect: ";
@@ -890,32 +912,71 @@ sub Menue($)
  
 #------------------------------------------------------------------------------
 # Prepare input for Data Menue. Allowed input formats:
-# INPUT1: 'value1 value2 ..'
 # INPUT2: [{'label'=>'Max','value'=>'foo'},{'label'=>'Tim','value'=>99}]
 #------------------------------------------------------------------------------
+sub _arrayHandler($$) {
+    my ($dataMenue,$opts) = @_;
+
+    foreach my $line ( @{$opts} ) {
+            next    if( ref $line ne 'HASH' );
+            next    if( ! defined $line-{'label'} );
+            next    if( ! defined $line-{'value'} );
+            push @{$dataMenue}, $line,
+    }
+    return 'ARRAY';
+}
+
+#------------------------------------------------------------------------------
+# Prepare input for Data Menue. Allowed input formats:
+# INPUT3: {}[, {'header'=>'','footer'=>''}]
+#------------------------------------------------------------------------------
+sub _hashHandler($$$) {
+    my ($dataMenue,$opts,$frame) = @_;
+
+    foreach my $l ( sort keys %{$opts} ) {
+        next    if( ref $opts->{$l} ne '' );
+        my $line = {'label' => $l, 'value' => $opts->{$l}};
+        push @{$dataMenue}, $line,
+    }
+    return 'HASH' if( ! defined $frame );
+
+    push @{$dataMenue}, {'header' => $frame->{'header'}} if( defined $frame->{'header'});
+    push @{$dataMenue}, {'footer' => $frame->{'footer'}} if( defined $frame->{'footer'});
+    return 'HASH';
+}
+
+
+#------------------------------------------------------------------------------
+# Prepare input for Data Menue. Allowed input formats:
+# INPUT1: 'value1 value2 ..'[, {'header'=>'','footer'=>''}]
+#------------------------------------------------------------------------------
+sub _scalarHandler($$$) {
+    my ($dataMenue,$opts,$frame) = @_;
+
+    my $i=1;
+    foreach my $l ( split /\s+/, $opts ) {
+        my $line = {'label' => 'V'.$i++, 'value' => $l};
+        push @{$dataMenue}, $line,
+    }
+    return 'SCALAR' if( ! defined $frame );
+    push @{$dataMenue}, {'header' => $frame->{'header'}} if( defined $frame->{'header'});
+    push @{$dataMenue}, {'footer' => $frame->{'footer'}} if( defined $frame->{'footer'});
+    return 'SCALAR';
+}
+
+#------------------------------------------------------------------------------
+# Prepare input for Data Menue. Allowed input formats:
+# INPUT1: 'value1 value2 ..'[, {'header'=>'','footer'=>''}]
+# INPUT2: [{'label'=>'Max','value'=>'foo'},{'label'=>'Tim','value'=>99}]
+# INPUT3: {}[, {'header'=>'','footer'=>''}]
+#------------------------------------------------------------------------------
 sub _addData($$$)
 {
     my ($dataMenue,$opts,$frame) = @_;
 
-    if(ref $opts eq 'ARRAY') {
-        foreach my $line ( @{$opts} ) {
-            next    if( ref $line ne 'HASH' );
-            next    if( ! defined $line-{'label'} );
-            next    if( ! defined $line-{'value'} );
-            push @{$dataMenue}, $line,
-         }
-         return 'ARRAY';
-    }elsif(ref $opts eq '' ) {
-        my $i=1;
-        foreach my $l ( split /\s+/, $opts ) {
-            my $line = {'label' => 'V'.$i++, 'value' => $l};
-            push @{$dataMenue}, $line,
-        }
-        return 'SCALAR' if( ! defined $frame );
-        push @{$dataMenue}, {'header' => $frame->{'header'}} if( defined $frame->{'header'});
-        push @{$dataMenue}, {'footer' => $frame->{'footer'}} if( defined $frame->{'footer'});
-        return 'SCALAR';
-    }
+    return _arrayHandler ($dataMenue,$opts)        if(ref $opts eq 'ARRAY');
+    return _hashHandler  ($dataMenue,$opts,$frame) if(ref $opts eq 'HASH' );
+    return _scalarHandler($dataMenue,$opts,$frame) if(ref $opts eq '' );
 }
 
 #------------------------------------------------------------------------------
@@ -928,18 +989,36 @@ sub _returnArray($) {
 }
 
 #------------------------------------------------------------------------------
-# Remove {label=>"EXIT"} line. Return values as white space concatenated string.
+# Remove {label=>"EXIT"} line. Return values as white space separated string.
 #------------------------------------------------------------------------------
 sub _returnScalar($) {
     my ($dataMenue) = @_;
 
     splice @{$dataMenue},0,1;
-    my     $data;
-    map {  $data .= $_->{'value'} .' '} @{$dataMenue};
+    my     $data='';
+    map { $data .= $_->{'value'} .' ' if( defined $_->{'value'})} @{$dataMenue};
     chop   $data;
     return $data;
 }
 
+#------------------------------------------------------------------------------
+# Remove {label=>"EXIT"}, header and footer lines.
+# Return values as white hash ref with 'label' as key and 'value' as value.
+#------------------------------------------------------------------------------
+sub _returnHash($) {
+    my ($dataMenue) = @_;
+
+    splice @{$dataMenue},0,1;
+    my     %data;
+    map {   if( defined $_->{'value'} && defined $_->{'label'} ){
+                my $k = $_->{'label'};
+                my $v = $_->{'value'};
+                $data{$k} = $v;
+            }
+        } @{$dataMenue};
+    return \%data;
+}
+
 #------------------------------------------------------------------------------
 # Use Menue to edit small data sets. Two input formats allowed.
 # INPUT1: 'value1 value2 ..'
@@ -955,8 +1034,9 @@ sub DataMenue(@) {
         my ($o,$dataMenue) = Menue($dataMenue);
         last if( $o == 0 );
     }
-    return _returnArray( $dataMenue) if( $format eq 'ARRAY' );
-    return _returnScalar($dataMenue) if( $format eq 'SCALAR');
+    return _returnArray ( $dataMenue) if( $format eq 'ARRAY' );
+    return _returnScalar($dataMenue)  if( $format eq 'SCALAR');
+    return _returnHash  ($dataMenue)  if( $format eq 'HASH'  );
 }
 #------------------------------------------------------------------------------
 #  Read a directory and return a hash with filenames stat() structure infos
